Learn R Programming

diseq (version 0.3.1)

equation_classes: Equation classes

Description

Equation classes

Arguments

Functions

  • equation_base-class: Equation base class

  • equation_basic-class: Basic disequilibrium model equation class

  • equation_deterministic_adjustment-class: Deterministic adjustment disequilibrium model equation class

  • equation_directional-class: Directional disequilibrium model equation class

  • equation_stochastic_adjustment-class: Stochastic adjustment disequilibrium model equation class

Slots

prefixed_specification

The equation formula using prefixed variables.

formula

The equation formula.

linear_model

The estimated equation using linear regression.

name

The name of the equation.

variable_prefix

A prefix string for the variables of the equation.

independent_variables

A vector with the right hand side variable names.

price_variable

The price variable name.

control_variables

Independent variables without the price variable.

independent_matrix

A model data matrix with columns corresponding to the set of independent variables.

price_vector

The vector of prices.

control_matrix

A model data matrix with columns corresponding to the set of independent variables without prices.

alpha_beta

A vector of right hand side coefficients.

alpha

The price coefficient.

beta

A vector of right hand side coefficient without the price coefficient.

var

The variance of the equation's shock.

sigma

The standard deviation of the equation's shock.

h

$$h_{x} = \frac{x - \mathrm{E} x}{\sqrt{\mathrm{Var} x}}$$

z

$$z_{xy} = \frac{h_{x} - \rho_{xy}h_{y}}{\sqrt{1 - \rho_{xy}^2}}$$

psi

$$\psi_{x} = \phi(h_{x})$$

Psi

$$\Psi_{x} = 1 - \Phi(z_{xy})$$

mu_Q

$$\mu_{Q} = \mathrm{E}Q$$

var_Q

$$V_{Q} = \mathrm{Var}Q$$

sigma_Q

$$\sigma_{Q} = \sqrt{\mathrm{Var}Q}$$

rho_QP

$$\rho_{Q} = \frac{\mathrm{Cov}(Q,P)}{\sqrt{\mathrm{Var}Q\mathrm{Var}P}}$$

rho_1QP

$$\rho_{1,QP} = \frac{1}{\sqrt{1 - \rho_{QP}}}$$

rho_2QP

$$\rho_{2,QP} = \rho_{QP}\rho_{1,QP}$$

sigma_QP

$$\sigma_{QP} = \mathrm{Cov}(Q,P)$$

h_Q

As in slot h

z_PQ

As in slot z

z_QP

As in slot z

separation_subset

A vector of indicators specifying the observations of the sample described by this equation according to the separation rule of the model.

Details

Classes with data and functionality describing equations of model systems.