Equation classes
equation_base-class: Equation base class
equation_basic-class: Basic disequilibrium model equation class
equation_deterministic_adjustment-class: Deterministic adjustment disequilibrium model equation
class
equation_directional-class: Directional disequilibrium model equation class
equation_stochastic_adjustment-class: Stochastic adjustment disequilibrium model equation class
prefixed_specificationThe equation formula using prefixed variables.
formulaThe equation formula.
linear_modelThe estimated equation using linear regression.
nameThe name of the equation.
variable_prefixA prefix string for the variables of the equation.
independent_variablesA vector with the right hand side variable names.
price_variableThe price variable name.
control_variablesIndependent variables without the price variable.
independent_matrixA model data matrix with columns corresponding to the set of independent variables.
price_vectorThe vector of prices.
control_matrixA model data matrix with columns corresponding to the set of independent variables without prices.
alpha_betaA vector of right hand side coefficients.
alphaThe price coefficient.
betaA vector of right hand side coefficient without the price coefficient.
varThe variance of the equation's shock.
sigmaThe standard deviation of the equation's shock.
h$$h_{x} = \frac{x - \mathrm{E} x}{\sqrt{\mathrm{Var} x}}$$
z$$z_{xy} = \frac{h_{x} - \rho_{xy}h_{y}}{\sqrt{1 - \rho_{xy}^2}}$$
psi$$\psi_{x} = \phi(h_{x})$$
Psi$$\Psi_{x} = 1 - \Phi(z_{xy})$$
mu_Q$$\mu_{Q} = \mathrm{E}Q$$
var_Q$$V_{Q} = \mathrm{Var}Q$$
sigma_Q$$\sigma_{Q} = \sqrt{\mathrm{Var}Q}$$
rho_QP$$\rho_{Q} = \frac{\mathrm{Cov}(Q,P)}{\sqrt{\mathrm{Var}Q\mathrm{Var}P}}$$
rho_1QP$$\rho_{1,QP} = \frac{1}{\sqrt{1 - \rho_{QP}}}$$
rho_2QP$$\rho_{2,QP} = \rho_{QP}\rho_{1,QP}$$
sigma_QP$$\sigma_{QP} = \mathrm{Cov}(Q,P)$$
h_QAs in slot h
z_PQAs in slot z
z_QPAs in slot z
separation_subsetA vector of indicators specifying the observations of the sample described by this equation according to the separation rule of the model.
Classes with data and functionality describing equations of model systems.