number_of_observations: Number of observations.
Description
Returns the number of observations that are used by an initialized model. The number
of used observations may differ from the numbers of observations of the data set
that was passed to the model's initialization.
Usage
number_of_observations(object)# S4 method for market_model
number_of_observations(object)
Value
The number of used observations.